SubsetCollectiveAnomalyDetector
========================================================================

.. currentmodule:: skchange.anomaly_detectors

.. autoclass:: SubsetCollectiveAnomalyDetector

.. include:: skchange.anomaly_detectors.SubsetCollectiveAnomalyDetector.examples

.. raw:: html

    <div class="clearer"></div>